#!/usr/bin/env python

#################################################################################################
# First order of business is always to make all other python modules accessible through the path
#################################################################################################

import sys
import os
import logging

sys.path.append(os.getcwd())

#################################################################################################
# Next, import the tools needed to initialize a data assimilation cycle
#################################################################################################

from da.tools.initexit import start_logger, parse_options, validate_opts_args, CycleControl

from da.tools.pipeline import ensemble_smoother_pipeline
from da.platform.maunaloa import MaunaloaPlatForm 
from da.ctgridded.dasystem import CtGriddedDaSystem 
from da.ctgridded.statevector import CtGriddedStateVector 
from da.ct.obs import CtObservations 

from da.tm5.observationoperator import TM5ObservationOperator 
from da.ct.optimizer import CtOptimizer
from da.tools.pipeline import header, footer

from da.analysis.expand_fluxes import save_weekly_avg_1x1_data, save_weekly_avg_state_data, save_weekly_avg_tc_data, save_weekly_avg_ext_tc_data
from da.analysis.expand_mixingratios import write_mixing_ratios

#################################################################################################
# Parse and validate the command line options, start logging
#################################################################################################

start_logger()

opts, args = validate_opts_args(parse_options())

#################################################################################################
# Create the Cycle Control object for this job    
#################################################################################################

DaCycle = CycleControl(opts, args)

PlatForm = MaunaloaPlatForm()
DaSystem = CtGriddedDaSystem(DaCycle['da.system.rc'])
ObsOperator = TM5ObservationOperator(DaCycle['da.obsoperator.rc'])
Samples = CtObservations()
StateVector = CtGriddedStateVector()
Optimizer = CtOptimizer()

##########################################################################################
################### ENTER THE PIPELINE WITH THE OBJECTS PASSED BY THE USER ###############
##########################################################################################

logging.info(header + "Entering Pipeline " + footer) 
ensemble_smoother_pipeline(DaCycle, PlatForm, DaSystem, Samples, StateVector, ObsOperator, Optimizer)


##########################################################################################
################### All done, extra stuff can be added next, such as analysis
##########################################################################################

logging.info(header + "Starting analysis" + footer) 

save_weekly_avg_1x1_data(DaCycle, StateVector)
save_weekly_avg_state_data(DaCycle, StateVector)
save_weekly_avg_tc_data(DaCycle, StateVector)
save_weekly_avg_ext_tc_data(DaCycle)
write_mixing_ratios(DaCycle)

sys.exit(0)


